==> lesstif_0.83.orig.tar.gz: lesstif-0.83/test/Xm/vasimple/test4.c <==
#include <X11/Intrinsic.h>
#include <Xm/RowColumn.h>
#include <Xm/PushB.h>
#include <Xm/XmP.h>

Widget rowcol;

void
cb(Widget w, int data, XtPointer cbs) {
	printf("cb %i\n",data);
}

int
main(int argc, char **argv)
{
  Widget toplevel;
  XtAppContext app;
  XmString s1, s2;
  Widget SimpleGadget;
  int which;
  XmSimpleMenuRec data;
  XtCallbackStatus cbs;

  XtSetLanguageProc(NULL, NULL, NULL);

  toplevel = XtVaAppInitialize(&app, "RowColumn", NULL, 0, &argc, argv, NULL, NULL);

  rowcol = XmCreateRowColumn(toplevel,"rc",NULL,0);
  XtManageChild(rowcol);

  which = 0;
  data.count = 1;
  data.post_from_button = 0;
  data.callback = cb;
  data.label_string = NULL;
  data.accelerator = NULL;
  data.accelerator_text = NULL;
  data.mnemonic = NULL;
  data.mnemonic_charset = NULL;
  data.button_type = NULL;
  data.button_set = 0;
  data.option_label = NULL;
  data.option_mnemonic = NULL;

  SimpleGadget = _XmCreateSimpleGadget("button_0",rowcol,
  					XmPUSHBUTTON,
  					&data,
  					which,
  					NULL,
  					NULL,0);

  cbs = XtHasCallbacks(SimpleGadget,XmNactivateCallback);
  switch (cbs)
  {
  case XtCallbackNoList:
  	printf("%s XtCallbackNoList\n",XtName(SimpleGadget));
  	break;
  case XtCallbackHasNone:
  	printf("%s XtCallbackHasNone\n",XtName(SimpleGadget));
  	break;
  case XtCallbackHasSome:
  	printf("%s XtCallbackHasSome\n",XtName(SimpleGadget));
  	break;
  default:
  	printf("%s unknown %i\n",XtName(SimpleGadget),cbs);
  	break;
  }

  XtRealizeWidget(toplevel);
  XtAppMainLoop(app);
  exit(0);
}

==> lesstif1-1_0.93.18.orig.tar.gz: lesstif-0.93.18/test/Xm/vasimple/test4.c <==
#include <X11/Intrinsic.h>
#include <Xm/RowColumn.h>
#include <Xm/PushB.h>
#include <Xm/XmP.h>

Widget rowcol;

void
cb(Widget w, int data, XtPointer cbs) {
	printf("cb %i\n",data);
}

int
main(int argc, char **argv)
{
#if 0
  Widget toplevel;
  XtAppContext app;
  XmString s1, s2;
  Widget SimpleGadget;
  int which;
  XmSimpleMenuRec data;
  XtCallbackStatus cbs;

  XtSetLanguageProc(NULL, NULL, NULL);

  toplevel = XtVaAppInitialize(&app, "RowColumn", NULL, 0, &argc, argv, NULL, NULL);

  rowcol = XmCreateRowColumn(toplevel,"rc",NULL,0);
  XtManageChild(rowcol);

  which = 0;
  data.count = 1;
  data.post_from_button = 0;
  data.callback = cb;
  data.label_string = NULL;
  data.accelerator = NULL;
  data.accelerator_text = NULL;
  data.mnemonic = NULL;
  data.mnemonic_charset = NULL;
  data.button_type = NULL;
  data.button_set = 0;
  data.option_label = NULL;
  data.option_mnemonic = NULL;

  SimpleGadget = _XmCreateSimpleGadget("button_0",rowcol,
  					XmPUSHBUTTON,
  					&data,
  					which,
  					NULL,
  					NULL,0);

  cbs = XtHasCallbacks(SimpleGadget,XmNactivateCallback);
  switch (cbs)
  {
  case XtCallbackNoList:
  	printf("%s XtCallbackNoList\n",XtName(SimpleGadget));
  	break;
  case XtCallbackHasNone:
  	printf("%s XtCallbackHasNone\n",XtName(SimpleGadget));
  	break;
  case XtCallbackHasSome:
  	printf("%s XtCallbackHasSome\n",XtName(SimpleGadget));
  	break;
  default:
  	printf("%s unknown %i\n",XtName(SimpleGadget),cbs);
  	break;
  }

  XtRealizeWidget(toplevel);
  
{
    static XtWidgetGeometry Expected[] = {
 
    };
    PrintDetails(  toplevel ,Expected);
};
  LessTifTestMainLoop(  toplevel );
  exit(0);
#else
  printf("This test doesn't work under lesstif or Motif-1.2 on sgi,\n"
	 "because the _XmCreateSimpleGadget routine isn't defined.\n"
	 "I've therefore commented out this test, and set it to\n"
	 "return with a 0 error code\n");
  exit (0);
#endif
}
